"""
   RiZoeLX 2022 © pyRiZoeLX
"""

from PhoenixScanner import Phoenix
import random

def random_token():
   Toks = ["RED7-yppfpzmakyopbjiwyccs", 
           "RED7-s7gforbm7iga1bj34qvlsa",
           "RED7-riw5wtg5mpjlcxi6jtjqhh",
           "RED7-cwnwhnzu305f24304nrs38",
           "RED7-gsgqo3eoab0vqsx1fw808",
          ]
   token = random.choice(Toks)
   return token


def update_scanlist(Red7):
   newlist = Red7.scanlist()
   if newlist == {'message': 'Invalid Token'}:
      newlist = Red7.scanlist()
      if newlist == {'message': 'Invalid Token'}:
         raise 'Invalid Scanner Token'
   return newlist


# [Pyrogram]
async def Red7_Watch(RiZoeL, message):
   Red7_Client = Phoenix(random_token())
   user = message.from_user
   msg = f"""
** Alert ⚠️**
User {user.mention} is officially
Scanned by Team Red7 | Phoenix API ;)

Appeal [Here](https://t.me/Red7WatchSupport)
   """
   try:
      try:
         check = Red7_Client.check(user.id)
         if check['is_gban']:
            try:
               await RiZoeL.ban_chat_member(message.chat.id, user.id)
            except:
               pass
            await RiZoeL.send_message(message.chat.id, msg, disable_web_page_preview=True)
      except:
         SCANLIST = []
         SCANLIST = update_scanlist(Red7_Client)
         if user.id in SCANLIST:
            try:
               await RiZoeL.ban_chat_member(message.chat.id, user.id)
            except:
               pass
            await RiZoeL.send_message(message.chat.id, msg, disable_web_page_preview=True)
   except Exception as error:
      print(str(error))


# [Telethon]
from telethon.tl import types, functions

RIGHTS = types.ChatBannedRights(
    until_date=None,
    view_messages=True,
    send_messages=True,
    send_media=True,
    send_stickers=True,
    send_gifs=True,
    send_games=True,
    send_inline=True,
    embed_links=True,
)

async def Red7_Watch_telethon(RiZoeL, message):
   user = message.sender_id
   Red7_Client = Phoenix(random_token())
   msg = f"""
 Alert ⚠️
User [{user}](tg://user?id={user}) is officially
Scanned by Team Red7 | Phoenix API ;)

Appeal [Here](https://t.me/Red7WatchSupport)
   """
   try:
      try:
         check = Red7_Client.check(user)
         if check['is_gban']:
            try:
                await RiZoeL(functions.channels.EditBannedRequest(message.chat_id, user, BANNED_RIGHTS))
            except BaseException:
                pass
            await RiZoeL.send_message(message.chat_id, msg, link_preview=False)
      except:
         SCANLIST = []
         SCANLIST = update_scanlist(Red7_Client)
         if user in SCANLIST:
            try:
                await RiZoeL(functions.channels.EditBannedRequest(message.chat_id, user, BANNED_RIGHTS))
            except BaseException:
                pass
            await RiZoeL.send_message(message.chat_id, msg, link_preview=False)
   except Exception as error:
      print(str(error))




"""
    RiZoeLX 2022 © pyRiZoeLX 
"""

import random
from RiZoeLX.data import admin_tags
#Errors
from pyrogram.errors import (ChatAdminRequired, RightForbidden, RPCError, UserNotParticipant)

async def ur(RiZoeL, message):
    try:
       args = message.text.split(" ", 1)[1].split(" ", 1)
    except IndexError:
       args = None

    if message.reply_to_message and message.reply_to_message.from_user:
       user = message.reply_to_message.from_user
       reason =  "".join(args) if args else ""

    elif args:
       reason = None
       user_ = args[0]
       if len(args) == 2:
           reason = args[1]
       if user_.isnumeric():
           user_ = int(user_)
       if not user_:
           await message.reply_text("I don't know who you're talking about, you're going to need to specify a user.!")
           return
       try:
           user = await RiZoeL.get_users(user_)
       except (TypeError, ValueError):
           await message.reply_text("Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them.")
           return
    else:
        await message.reply_text("I don't know who you're talking about, you're going to need to specify a user...!")
        return 

    return user, reason

#Get user only
async def u(RiZoeL, message):
    try:
       args = message.text.split(" ", 1)[1].split(" ", 1)
    except IndexError:
       args = None

    if message.reply_to_message and message.reply_to_message.from_user:
       user = message.reply_to_message.from_user

    elif args:
       user_ = args[0]
       if user_.isnumeric():
           user_ = int(user_)
       if not user_:
           await message.reply_text("I don't know who you're talking about, you're going to need to specify a user.!")
           return
       try:
           user = await RiZoeL.get_users(user_)
       except (TypeError, ValueError):
           await message.reply_text("Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them.")
           return
    else:
        await message.reply_text("I don't know who you're talking about, you're going to need to specify a user...!")
        return

    return user


async def ban_user(RiZoeL, message):
   user, reason = ur(RiZoeL, message)
   try:
      await RiZoeL.ban_chat_member(message.chat.id, user.id)
   except ChatAdminRequired:
      await message.reply_text("I'm not admin or I don't have rights.")
      return
   except RightForbidden:
      await message.reply_text("I don't have enough rights to ban this user.")
      return 
   except UserNotParticipant:
      await message.reply_text("How can I ban a user who is not a part of this chat?")
      return 
   except RPCError as eror:
      await message.reply_text(str(eror))
      return 

   if reason:
      await message.reply_text(f"Banned {user.mention}! \nReason: {reason}")
   else:
      await message.reply_text(f"Banned {user.mention}!")

async def unban_user(RiZoeL, message):
   user, reason = await ur(RiZoeL, message)
   try:
      await RiZoeL.unban_chat_member(message.chat.id, user.id)
   except ChatAdminRequired:
      await message.reply_text("I'm not admin or I don't have rights.")
      return
   except RightForbidden:
      await message.reply_text("I don't have enough rights to ban this user.")
      return  
   except RPCError as eror:
      await message.reply_text(str(eror))
      return 

   if reason:
      await message.reply_text(f"Unbanned {user.mention}! \nReason: {reason}")
   else:
      await message.reply_text(f"Unbanned {user.mention}!")

async def promote_user(RiZoeL, message):
  chat = message.chat.id
  user, tag = await ur(RiZoeL, message)
  if tag:
    admin_tag = tag
  else:
    if user.is_bot:
      admin_tag = random.choice(bot_tags)
    else:
      admin_tag = random.choice(admin_tags)
  try:
     await RiZoeL.promote_chat_member(chat.id, user.id,
            can_change_info=False,
            can_post_messages=True,
            can_edit_messages=True,
            can_delete_messages=True,
            can_restrict_members=False,
            can_invite_users=True,
            can_pin_messages=True,
            can_promote_members=False,
            )
     await RiZoeL.set_administrator_title(chat.id, user.id, admin_tag)
     await message.reply_text(f"Promoted {user.mention}!")
  except ChatAdminRequired:
     await message.reply_text("I'm not admin or I don't have rights.")
  except RightForbidden:
     await message.reply_text("I don't have enough rights to ban this user.")
  except UserNotParticipant:
     await message.reply_text("How can I promote a user who is not a part of this chat?")
  except RPCError as eror:
     await message.reply_text(str(eror))

async def demote_user(RiZoeL, message):
  chat = message.chat.id
  user = await u(RiZoeL, message)
  try:
     await RiZoeL.promote_chat_member(chat.id, user.id,
            is_anonymous=False,
            can_change_info=False,
            can_post_messages=False,
            can_edit_messages=False,
            can_delete_messages=False,
            can_restrict_members=False,
            can_invite_users=False,
            can_pin_messages=False,
            can_promote_members=False,
            )
     await message.reply_text(f"Demoted {user.mention}!")
  except ChatAdminRequired:
     await message.reply_text("I'm not admin or I don't have rights.")
  except RightForbidden:
     await message.reply_text("I don't have enough rights to ban this user.")
  except UserNotParticipant:
     await message.reply_text("How can I demote a user who is not a part of this chat?")
  except RPCError as eror:
     await message.reply_text(str(eror))


from pyrogram.types import ChatPermissions

async def mute_user(RiZoeL, message):
   user, reason = await ur(RiZoeL, message)
   try:
      await RiZoeL.restrict_chat_member(message.chat.id, user.id, ChatPermissions())
   except ChatAdminRequired:
      await message.reply_text("I'm not admin or I don't have rights.")
      return
   except RightForbidden:
      await message.reply_text("I don't have enough rights to ban this user.")
      return 
   except UserNotParticipant:
      await message.reply_text("How can I mute a user who is not a part of this chat?")
      return 
   except RPCError as eror:
      await message.reply_text(str(eror))
      return

   if reason:
      await message.reply_text(f"Muted {user.mention}! \nReason: {reason}")
   else:
      await message.reply_text(f"Muted {user.mention}!")

async def unmute_user(RiZoeL, message):
   user, reason = await ur(RiZoeL, message)
   try:
      await message.chat.unban_member(user.id) 
   except ChatAdminRequired:
      await message.reply_text("I'm not admin or I don't have rights.")
      return
   except RightForbidden:
      await message.reply_text("I don't have enough rights to ban this user.")
      return
   except RPCError as eror:
      await message.reply_text(str(eror))
      return

   if reason:
      await message.reply_text(f"Unuted {user.mention}! \nReason: {reason}")
   else:
      await message.reply_text(f"Unuted {user.mention}!")
  



"""
   RiZoeLX 2022-2023 © pyRiZoeLX 
"""

from pytgcalls import StreamType
from pytgcalls.types.input_stream import AudioPiped

async def play_audio(RiZoeL, message, pytg, audio, chat):
   try:
      await RiZoeL.join_chat(chat)
   except Exception as err:
      await message.reply_text(str(err))
      return
   await pytg.join_group_call(chat, AudioPiped(audio), stream_type=StreamType().pulse_stream)



from .spamx import *
from .tags import *
from .usage_data import *
from .vars import *

Dev = "@TheRiZoeL"
R7_ban_codes = "R7x00|R7x01|R7x02|R7x03|R7x04|R7x05|R7x06|R7x07|R7x08|R7x09|R7x10|R7x11|R7x12|R7x13|R7x14|R7x15|R7x16|R7x17|R7x18" 



"""
   RiZoeLX 2022 © SpamX
"""

Variables = [
   "OWNER_ID",
   "SUDO_USERS",
   "LOGS_CHANNEL",
   "HNDLR",
   "ALIVE_PIC",
   "ALIVE_MSG",
   "PING_MSG",
   "CLIENT",
   "CLIENT2",
   "CLIENT3",
   "CLIENT4",
   "CLIENT5",
   "CLIENT6",
   "CLIENT7",
   "CLIENT8",
   "CLIENT9",
   "CLIENT10",
   "CLIENT11",
   "CLIENT12",
   "CLIENT13",
   "CLIENT14",
   "CLIENT15",
   "CLIENT16",
   "CLIENT17",
   "CLIENT18",
   "CLIENT19",
   "CLIENT20",
]
 
Variables_text =  "`OWNER_ID`, `SUDO_USERS`, `LOGS_CHANNEL`, `HNDLR`, `ALIVE_PIC`, `ALIVE_MSG`, `PING_MSG`, `CLIENT`, `CLIENT2`, `CLIENT3`, `CLIENT4`, `CLIENT5`, `CLIENT6`, `CLIENT7`, `CLIENT8`, `CLIENT9`, `CLIENT10`, `CLIENT11`, `CLIENT12`, `CLIENT13`, `CLIENT14`, `CLIENT15`, `CLIENT16`, `CLIENT17`, `CLIENT18`, `CLIENT19`, `CLIENT20`"


"""
   © RiZoeLX - SpamX
   functions of RiZoeLX/SpamX
"""

from RiZoeLX.developers import *
from RiZoeLX.data import *
import random, asyncio, re

async def dor(message, editor, text):
   try:
     await editor.edit_text(text)
   except:
     await editor.delete()
     await message.reply_text(text)

res_devs = "RiZoeL|Mahipal|Akash|TheRiZoeL|TheVenomXD"
res_grps = [1517994352, 1789859817, -1001321613309, 1321613309, 1001749467927, 1749467927]


""" Get User with Reason! """
async def user_reason(RiZoeL, message, Owner, Sudos):
    try:
       args = message.text.split(" ", 1)[1].split(" ", 1)
    except IndexError:
       args = None

    if message.reply_to_message and message.reply_to_message.from_user:
       user = message.reply_to_message.from_user
       reason =  "".join(args) if args else ""

    elif args:
       reason = None
       user_ = args[0]
       if len(args) == 2:
           reason = args[1]
       if user_.isnumeric():
           user_ = int(user_)
       if not user_:
           await message.reply_text("I don't know who you're talking about, you're going to need to specify a user.!")
           return
       try:
           user = await RiZoeL.get_users(user_)
       except (TypeError, ValueError):
           await message.reply_text("Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them.")
           return
    else:
        await message.reply_text("I don't know who you're talking about, you're going to need to specify a user...!")
        return 

    if int(user.id) in Devs:
        await message.reply_text(f"{user.mention} is Owner/Dev of @RiZoeLX")
        return
    if int(user.id) == Owner:
        await message.reply_text(f"{user.mention} is owner of these bots!")
        return
    if int(user.id) in Sudos:
      if message.from_user.id != Owner:
         await message.reply_text(f"{user.mention} is Sudo User!")
         return

    return user, reason

async def user_only(RiZoeL, message, Owner, Sudos):
    try:
       args = message.text.split(" ", 1)[1].split(" ", 1)
    except IndexError:
       args = None

    if message.reply_to_message and message.reply_to_message.from_user:
       user = message.reply_to_message.from_user

    elif args:
       user_ = args[0]
       if user_.isnumeric():
           user_ = int(user_)
       if not user_:
           await message.reply_text("I don't know who you're talking about, you're going to need to specify a user.!")
           return
       try:
           user = await RiZoeL.get_users(user_)
       except (TypeError, ValueError):
           await message.reply_text("Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them.")
           return
    else:
        await message.reply_text("I don't know who you're talking about, you're going to need to specify a user...!")
        return 

    if int(user.id) in Devs:
        await message.reply_text(f"{user.mention} is Owner/Dev of @RiZoeLX")
        return
    if int(user.id) == Owner:
        await message.reply_text(f"{user.mention} is owner of these bots!")
        return
    if int(user.id) in Sudos:
      if message.from_user.id != Owner:
         await message.reply_text(f"{user.mention} is Sudo User!")
         return

    return user

"""Spam functions"""
async def start_raid(RiZoeL, message, counts, user):
   chat = message.chat
   if chat.id in res_grps:
      await message.reply_text("**Sorry!** I can't raid here.")
      return
   if int(user.id) in Devs:
      await message.reply_text("I can't raid on @RiZoeLX's Owner")
      return
   for _ in range(counts):
      raid = random.choice(raids.raid)
      await RiZoeL.send_message(chat.id, f"{user.mention} {raid}")
      await asyncio.sleep(0.3) 

async def start_spam(RiZoeL, message, counts, spam_text):
   chat = message.chat
   if chat.id in res_grps:
      await message.reply_text("**Sorry!** I can't spam here.")
      return
   if re.search(res_devs.lower(), spam_text.lower()):
      await message.reply_text("**Error!**")
      return
   for _ in range(counts):
      await RiZoeL.send_message(chat.id, f"{spam_text} \n\n #{message.from_user.first_name} \n #SpamX -")
      await asyncio.sleep(0.3)

async def start_dm_raid(RiZoeL, message, counts, user):
   if int(user) in Devs:
      await message.reply_text("User is Dev of SpamX:)")
      return 
   for _ in range(counts):
      raid = random.choice(raids.raid)
      await RiZoeL.send_message(user, raid)
      await asyncio.sleep(0.3) 

async def start_dm_spam(RiZoeL, counts, user_id, spam_text):
   if int(user_id) in Devs:
      await message.reply_text("User is Dev of SpamX:)")
      return 
   for _ in range(counts):
      await RiZoeL.send_message(user_id, str(spam_text))
      await asyncio.sleep(0.3) 

async def start_dspam(RiZoeL, message, counts, delay, spam_text):
   chat = message.chat
   if chat.id in res_grps:
      await message.reply_text("**Sorry!** I can't spam here.")
      return
   if re.search(res_devs.lower(), spam_text.lower()):
      await message.reply_text("**Error!**")
      return
   for _ in range(counts):
      await RiZoeL.send_message(chat.id, f"{spam_text} \n\n #{message.from_user.first_name} \n #SpamX -")
      await asyncio.sleep(delay)

async def start_pspam(RiZoeL, message, counts):
   chat = message.chat
   if chat.id in res_grps:
      await message.reply_text("**Sorry!** I can't spam here.")
      return
   for _ in range(counts):
      prn = random.choice(plinks)
      if ".jpg" in prn or ".png" in prn:
        await RiZoeL.send_photo(chat.id, prn)
        await asyncio.sleep(0.4)
      if ".mp4" in prn or ".MP4," in prn:
        await RiZoeL.send_video(chat.id, prn)
        await asyncio.sleep(0.4)

""" Global Functions"""
async def start_gban(RiZoeL, message, user, reason):
    try:    
       x = await message.reply_text("Gbanning...")
       common = await RiZoeL.get_common_chats(user.id)
       done = 0
       fuck = 0
       if not common:
          await dor(message, x, f"User {user.mention} got no common chats with the specified one.")
          return
       for cht in common:  
         try:
           await RiZoeL.ban_chat_member(cht.id, user.id)
           done += 1
         except:
           fuck += 1
       await dor(message, x, f"user {user.mention} added in GBAN list!")

    except Exception as a:
      await message.reply_text(str(a))
      pass

async def start_ungban(RiZoeL, message, user):      
    try:
       x = await message.reply_text("Gbanning...")
       common = await RiZoeL.get_common_chats(user.id)
       done = 0
       fuck = 0
       if not common:
         await dor(message, x, f"User {user.mention} got no common chats with the specified one.")
         return
       for cht in common:  
         try:
           await RiZoeL.unban_chat_member(cht.id, user.id)
           done += 1
         except:
           fuck += 1
       await dor(message, x, f"user {user.mention} added in UNGBAN list!")

    except Exception as a:
      await message.reply_text(str(a))
      pass


async def start_gpromote(RiZoeL, message, user):
   x = await message.reply_text("promoting globally...")
   common = await RiZoeL.get_common_chats(user.id)
   chat_len = len(common)
   if not common:
      await dor(message, x, f"User {user.mention} got no common chats with the specified one.")
      return
   for cht in common:  
      try:
         await RiZoeL.promote_chat_member(cht.id, user.id, 
              can_change_info=True,
              can_manage_video_chats=True,
              can_delete_messages=True,
              can_restrict_members=True,
              can_invite_users=True,
              can_pin_messages=True,
              )
         done += 1
      except:
         fuck += 1
   await dor(message, x, f"User Globally Promoted ✓ \n\n User: {user.mention} \n total common chats: `{chat_len}` \n Promoted in `{done}` chats \n Failed in `{fuck}` chats")

async def start_gdemote(RiZoeL, message, user):
   x = await message.reply_text("demoting globally...")
   common = await RiZoeL.get_common_chats(user.id)
   chat_len = len(common)
   if not common:
      await dor(message, x, f"User {user.mention} got no common chats with the specified one.")
      return
   for cht in common:  
      try:
         await RiZoeL.promote_chat_member(cht.id, user.id, 
              can_change_info=False,
              can_manage_video_chats=False,
              can_delete_messages=False,
              can_restrict_members=False,
              can_invite_users=False,
              can_pin_messages=False,
              )
         done += 1
      except:
         fuck += 1
   await dor(message, x, f"User Globally demoted ✓ \n\n User: {user.mention} \n total common chats: `{chat_len}` \n Promoted in `{done}` chats \n Failed in `{fuck}` chats")
   

async def start_banall(RiZoeL, message):
   chat = message.chat
   x = RiZoeL.send_message("Hey it's SpamX!")
   done = 0
   failed = 0
   async for u in RiZoeL.get_chat_members(chat.id):
      user = u.user
      try:
         await RiZoeL.ban_chat_member(chat.id, user.id)
         done += 1
      except Exception as err:
         print(f"pyRiZoeLX - [INFO]: {str(err)}")
         failed += 1
   await x.delete()
   await RiZoeL.send_message(chat.id, f"Members Banned ✓ \n\n Banned {done} users\n failed {failed}")

async def get_time(seconds: int) -> str:
    count = 0
    up_time = ""
    time_list = []
    time_suffix_list = ["s", "m", "h", "days"]
    while count < 4:
        count += 1
        remainder, result = divmod(seconds, 60) if count < 3 else divmod(seconds, 24)
        if seconds == 0 and remainder == 0:
            break
        time_list.append(int(result))
        seconds = int(remainder)
    hmm = len(time_list)
    for x in range(hmm):
        time_list[x] = str(time_list[x]) + time_suffix_list[x]
    if len(time_list) == 4:
        up_time += time_list.pop() + ", "
    time_list.reverse()
    up_time += ":".join(time_list)
    return up_time

def start_spamX(RiZoeLX, type):
    if type == "token":
      RiZoeLX.start()
      try:
         x = RiZoeLX.get_me()
         print(f"pyRiZoeLX - [INFO]: @{x.username} started ✓")
      except:
         print(f"pyRiZoeLX - [INFO]: Bot started ✓")
    else:
      RiZoeLX.start()
      try:
         try:
           RiZoeLX.join_chat("RiZoeLX")
           RiZoeLX.join_chat("DNHxHELL")
         except:
           pass
         x = RiZoeLX.get_me()
         print(f"pyRiZoeLX - [INFO]: @{x.first_name} started ✓")
      except:
         try:
           RiZoeLX.join_chat("RiZoeLX")
           RiZoeLX.join_chat("DNHxHELL")
         except:
           pass
         print(f"pyRiZoeLX - [INFO]: Client started ✓")

def check_logchannel(chat_id):
   if chat_id in res_grps:
      return True
   else:
      return False



"""
   © RiZoeLX
   SpamX - 2022
   Note: function is only for ID not for Bots!
"""


async def broadcast_(RiZoeL, message):
    ok = message.from_user.id
    txt = ' '.join(message.command[1:])
    if txt:
      msg = str(txt)
    elif message.reply_to_message:
        msg = message.reply_to_message.text.markdown
    else:
        await message.reply_text("Give Message for Broadcast or reply to any msg")
        return

    await message.reply_text("__Broadcasting__")
    err = 0
    dn = 0

    async for cht in RiZoeL.get_dialogs():
          try:
                await RiZoeL.send_message(cht.chat.id, msg, disable_web_page_preview=True)
                dn += 1
                await asyncio.sleep(0.1)
          except Exception as e:
              err += 1 
    return await RiZoeL.send_message(ok, f"**• Broadcast Done** ✅ \n\n Chats: {dn} \n Failed In {err} chats")



""" 
   This File is for RiZoeLX/SpamX
   Data's of SpamX!
"""


class raids:
     raid = [
     "мα∂αя¢нσ∂ тєяι мαα кι ¢нυт мє gнυткα кнααкє тнσσк ∂υиgα 🤣🤣",    
      "тєяє вєнєи к ¢нυт мє ¢нαкυ ∂ααℓ кαя ¢нυт кα кнσσи кαя ∂υgα",     
      "тєяι ναнєєи инι нαι куα? 9 мαнιиє яυк ѕαgι ναнєєи ∂єтα нυ 🤣🤣🤩",    
      "тєяι мαα к внσѕ∂є мє αєяσρℓαиєραяк кαякє υ∂ααи внαя ∂υgα ✈️🛫",    
      "тєяι мαα кι ¢нυт мє ѕυтℓι вσмв fσ∂ ∂υиgα тєяι мαα кι נнααтє נαℓ кє кнααк нσ נαуєgι💣",    
      "тєяι мααкι ¢нυт мє ѕ¢σσтєя ∂ααℓ ∂υgα👅",     
      "тєяє вєнєи к ¢нυт мє ¢нαкυ ∂ααℓ кαя ¢нυт кα кнσσи кαя ∂υgα",     
      "тєяє вєнєи к ¢нυт мє ¢нαкυ ∂ααℓ кαя ¢нυт кα кнσσи кαя ∂υgα",     
      "тєяι мαα кι ¢нυт кαктє 🤱 gαℓι кє кυттσ 🦮 мє вααт ∂υиgα ρнιя 🍞 вяєα∂ кι тαян кнαуєиgє ωσ тєяι мαα кι ¢нυт",     
      "∂υ∂н нιℓααυиgα тєяι ναнєєи кє υρя иι¢нє 🆙🆒😙",     
      "тєяι мαα кι ¢нυт мє ✋ нαттн ∂αℓкє 👶 вα¢¢нє иιкαℓ ∂υиgα 😍",     
      "тєяι вєни кι ¢нυт мє кєℓє кє ¢нιℓкє 🍌🍌😍",     
      "тєяι внєи кι ¢нυт мє υѕєявσт ℓαgααυиgα ѕαѕтє ѕραм кє ¢нσ∂є",     
      "тєяι ναнєєи ∂нαи∂нє νααℓι 😋😛",     
      "тєяι мαα кє внσѕ∂є мє α¢ ℓαgα ∂υиgα ѕααяι gαямι иιкαℓ נααуєgι",     
      "тєяι ναнєєи кσ нσяℓι¢кѕ ρєєℓαυиgα мα∂αя¢нσ∂😚",     
      "тєяι мαα кι gααи∂ мє ѕαяιуα ∂ααℓ ∂υиgα мα∂αя¢нσ∂ υѕι ѕαяιує ρя тαиg кє вα¢нє ραι∂α нσиgє 😱😱",     
      "тєяι мαα кσ кσℓкαтα νααℓє נιтυ внαιуα кα ℓυи∂ мυвαяαк 🤩🤩",    
      "тєяι мυмму кι fαитαѕу нυ ℓαω∂є, тυ αρиι внєи кσ ѕмвнααℓ 😈😈",     
      "тєяα ρєнℓα вααρ нυ мα∂αя¢нσ∂ ",     
      "тєяι ναнєєи кє внσѕ∂є мє χνι∂єσѕ.¢σм ¢нαℓα кє мυтн мααяυиgα 🤡😹",     
      "тєяι мαα кα gяσυρ νααℓσи ѕααтн мιℓкє gαиg вαиg кяυиgα🙌🏻☠️ ",     
      "тєяι ιтєм кι gααи∂ мє ℓυи∂ ∂ααℓкє,тєяє נαιѕα єк σя иιкααℓ ∂υиgα мα∂αя¢нσ∂🤘🏻🙌🏻☠️ ",     
      "αυкααт мє яєн νяиα gααи∂ мє ∂αи∂α ∂ααℓ кє мυн ѕє иιкααℓ ∂υиgα ѕнαяιя внι ∂αи∂є נєѕα ∂ιкнєgα 🙄🤭🤭",     "тєяι мυмму кє ѕααтн ℓυ∂σ кнєℓтє кнєℓтє υѕкє мυн мє αρиα ℓσ∂α ∂є ∂υиgα☝🏻☝🏻😬",     
      "тєяι ναнєєи кσ αρиє ℓυи∂ ρя ιтиα נнυℓααυиgα кι נнυℓтє נнυℓтє нι вα¢нα ραι∂α кя ∂єgι👀👯 ",    
      "тєяι мαα кι ¢нυт мєι вαттєяу ℓαgα кє ρσωєявαик вαиα ∂υиgα 🔋 🔥🤩",     
      "тєяι мαα кι ¢нυт мєι ¢++ ѕтяιиg єи¢яуρтισи ℓαgα ∂υиgα вαнтι нυуι ¢нυт яυк נαуєgιιιι😈🔥😍",     
      "тєяι мαα кє gααи∂ мєι נнαα∂υ ∂αℓ кє мσя 🦚 вαиα ∂υиgαα 🤩🥵😱",     
      "тєяι ¢нυт кι ¢нυт мєι ѕнσυℓ∂єяιиg кαя ∂υиgαα нιℓαтє нυує внι ∂αя∂ нσgααα😱🤮👺",     
      "тєяι мαα кσ яє∂ι ρє вαιтнαℓ кє υѕѕє υѕкι ¢нυт вιℓωαυиgαα 💰 😵🤩",     
      "внσѕ∂ιкє тєяι мαα кι ¢нυт мєι 4 нσℓє нαι υимє мѕєαℓ ℓαgα вαнυт вαнєтι нαι внσf∂ιкє👊🤮🤢🤢",     
      "тєяι вαнєи кι ¢нυт мєι вαяgα∂ кα ρє∂ υgα ∂υиgαα ¢σяσиα мєι ѕαв σχуgєи ℓєкαя נαуєиgє🤢🤩🥳",    
      "тєяι мαα кι ¢нυт мєι ѕυ∂σ ℓαgα кє вιgѕραм ℓαgα кє 9999 fυ¢к ℓαgαα ∂υ 🤩🥳🔥",     
      "тєяι ναнєи кє внσѕ∂ιкє мєι вєѕαи кє ℓα∂∂υ внαя ∂υиgα🤩🥳🔥😈",     
      "тєяι мαα кι ¢нυт кнσ∂ кє υѕмє ¢уℓιи∂єя ⛽️ fιт кαякє υѕмєє ∂αℓ мαкнαиι вαиαυиgααα🤩👊🔥",    
      "тєяι мαα кι ¢нυт мєι ѕнєєѕнα ∂αℓ ∂υиgααα αυя ¢нαυяαнє ρє тααиg ∂υиgα внσѕ∂ιкє😈😱🤩",   
      "тєяι мαα кι ¢нυт мєι ¢яє∂ιт ¢αя∂ ∂αℓ кє αgє ѕє 500 кє кααяє кααяє иσтє иιкαℓυиgαα внσѕ∂ιкє💰💰🤩",
      "тєяι мαα кє ѕαтн ѕυαя кα ѕєχ кαяωα ∂υиgαα єк ѕαтн 6-6 вα¢нє ∂єgι💰🔥😱",    
      "тєяι вαнєи кι ¢нυт мєι αρρℓє кα 18ω ωαℓα ¢нαяgєя 🔥🤩",     
      "тєяι вαнєи кι gααи∂ мєι σиєρℓυѕ кα ωяαρ ¢нαяgєя 30ω нιgн ρσωєя 💥😂😎",   
      "тєяι вαнєи кι ¢нυт кσ αмαzσи ѕє σя∂єя кαяυиgα 10 яѕ мєι αυя fℓιρкαят ρє 20 яѕ мєι вє¢н ∂υиgα🤮👿😈🤖",
      "тєяι мαα кι вα∂ι внυи∂ мє zσмαтσ ∂αℓ кє ѕυвωαу кα вff νєg ѕυв ¢σмвσ [15¢м , 16 ιи¢нєѕ ] σя∂єя ¢σ∂ кяναυиgα σя тєяι мαα נαв ∂ιℓινєяу ∂єиє αуєgι тαв υѕρє נαα∂υ кяυиgα σя fιя 9 мσитн вαα∂ νσ єк σя fяєє ∂ιℓινєяу ∂єgι🙀👍🥳🔥",     
      "тєяι внєи кι ¢нυт кααℓι🙁🤣💥",     
      "тєяι мαα кι ¢нυт мє ¢нαиgєѕ ¢σммιт кяυgα fιя тєяι внєєи кι ¢нυт αυтσмαтι¢αℓℓу υρ∂αтє нσנααуєgι"
      "тєяι мαυѕι кє внσѕ∂є мєι ιи∂ιαи яαιℓωαу 🚂💥😂",     
      "тυ тєяι вαнєи тєяα кнαи∂αи ѕαв вαнєи кє ℓαω∂є яαи∂ι нαι яαи∂ι 🤢✅🔥",   
      "тєяι вαнєи кι ¢нυт мєι ισиι¢ вσи∂ вαиα кє νιяgιиιту ℓσσѕє кαяωα ∂υиgα υѕкι 📚 😎🤩",    
      "тєяι яαи∂ι мαα ѕє ρυ¢ниα вααρ кα иααм вαнєи кє ℓσ∂єєєєє 🤩🥳😳",    
      "тυ αυя тєяι мαα ∂σиσ кι внσѕ∂є мєι мєтяσ ¢нαℓωα ∂υиgα мα∂αяχнσ∂ 🚇🤩😱🥶",     
      "тєяι мαα кσ ιтиα ¢нσ∂υиgα тєяα вααρ внι υѕкσ ραн¢нαиαиє ѕє мαиα кαя ∂єgα😂👿🤩",     
      "тєяι вαнєи кє внσѕ∂є мєι нαιя ∂яуєя ¢нαℓα ∂υиgαα💥🔥🔥",     
      "тєяι мαα кι ¢нυт мєι тєℓєgяαм кι ѕαяι яαи∂ιуσи кα яαи∂ι кнαиα кнσℓ ∂υиgαα👿🤮😎",   
      "тєяι мαα кι ¢нυт αℓєχα ∂αℓ кєє ∂נ вαנαυиgααα 🎶 ⬆️🤩💥",     
      "тєяι мαα кє внσѕ∂є мєι gιтнυв ∂αℓ кє αρиα вσт нσѕт кαяυиgαα 🤩👊👤😍",     
      "тєяι вαнєи кα νρѕ вαиα кє 24*7 вαѕн ¢нυ∂αι ¢σммαи∂ ∂є ∂υиgαα 🤩💥🔥🔥",     
      "тєяι мυмму кι ¢нυт мєι тєяє ℓαи∂ кσ ∂αℓ кє кααт ∂υиgα мα∂αя¢нσ∂ 🔪😂🔥",     
      "ѕυи тєяι мαα кα внσѕ∂α αυя тєяι вαнєи кα внι внσѕ∂α 👿😎👊",     
      "тυנнє ∂єкн кє тєяι яαи∂ι вαнєи ρє тαяαѕ αтα нαι мυנнє вαнєи кє ℓσ∂єєєє 👿💥🤩🔥",     
      "ѕυи мα∂αя¢нσ∂ נуα∂α иα υ¢нαℓ мαα ¢нσ∂ ∂єиgє єк мιи мєι ✅🤣🔥🤩",     
      "αρиι αммα ѕє ρυ¢ниα υѕкσ υѕ кααℓι яααт мєι кαυи ¢нσ∂иєє αуα тнααα! тєяє ιѕ ραρα кα иααм ℓєgι 😂👿😳",  
      "тσнαя вαнιи ¢нσ∂υ ввαнєи кє ℓαω∂є υѕмє мιттι ∂αℓ кє ¢ємєит ѕє внαя ∂υ 🏠🤢🤩💥",     
      "тυנнє αв тαк иαнι ѕмנн αуα кι мαι нι нυ тυנнє ραι∂α кαяиє ωαℓα внσѕ∂ιкєє αρиι мαα ѕє ρυ¢н яαи∂ι кє вα¢нєєєє 🤩👊👤😍",     
      "тєяι мαα кє внσѕ∂є мєι ѕρσтιfу ∂αℓ кє ℓσfι вαנαυиgα ∂ιи внαя 😍🎶🎶💥",     
      "тєяι мαα кα иαуα яαи∂ι кнαиα кнσℓυиgα ¢нιитα мαт кαя 👊🤣🤣😳",     
      "тєяα вααρ нυ внσѕ∂ιкє тєяι мαα кσ яαи∂ι кнαиє ρє ¢нυ∂ωα кє υѕ ραιѕє кι ∂ααяυ ρєєтα нυ 🍷🤩🔥",     
      "тєяι вαнєи кι ¢нυт мєι αρиα вα∂α ѕα ℓσ∂α gнυѕѕα ∂υиgαα кαℓℓααρ кє мαя נαуєgι 🤩😳😳🔥",     
      "тσнαя мυмму кι ¢нυт мєι ρυяι кι ρυяι кιиgfιѕнєя кι вσттℓє ∂αℓ кє тσ∂ ∂υиgα αи∂єя нι 😱😂🤩",     
      "тєяι мαα кσ ιтиα ¢нσ∂υиgα кι ѕαρиє мєι внι мєяι ¢нυ∂αι уαα∂ кαяєgι яαи∂ι 🥳😍👊💥",     
      "тєяι мυмму αυя вαнєи кσ ∂αυ∂α ∂αυ∂α иє ¢нσ∂υиgα υикє иσ вσℓиє ρє внι ℓαи∂ gнυѕα ∂υиgα αи∂єя тαк 😎😎🤣🔥",     
      "тєяι мυмму кι ¢нυт кσ σиℓιиє σℓχ ρє вє¢нυиgα αυя ραιѕє ѕє тєяι вαнєи кα кσтнα кнσℓ ∂υиgα 😎🤩😝😍",    
      "тєяι мαα кє внσѕ∂α ιтиα ¢нσ∂υиgα кι тυ ¢αн кє внι ωσ мαѕт ¢нυ∂αι ѕє ∂υя инι נα ραуєgαα 😏😏🤩😍",     
      "ѕυи вє яαи∂ι кι αυℓαα∂ тυ αρиι вαнєи ѕє ѕєєкн кυ¢н кαιѕє gααи∂ мαяωαтє нαι😏🤬🔥💥",     
      "тєяι мαα кα уααя нυ мєι αυя тєяι вαнєи кα ρуααя нυ мєι αנα мєяα ℓαи∂ ¢нσσѕ ℓє 🤩🤣💥",     
      "тєяι внєи кι ¢нυт мє υѕєявσт ℓαgααυиgα ѕαѕтє ѕραм кє ¢нσ∂є",    
      "тєяι мαα кι gααи∂ мє ѕαяιуα ∂ααℓ ∂υиgα мα∂αя¢нσ∂ υѕι ѕαяιує ρя тαиg кє вα¢нє ραι∂α нσиgє 😱😱",     
      "тєяι мαα кι ¢нυт мє ✋ нαттн ∂αℓкє 👶 вα¢¢нє иιкαℓ ∂υиgα 😍",     
      "тєяι вєни кι ¢нυт мє кєℓє кє ¢нιℓкє 🤤🤤",     
      "тєяι мαα кι ¢нυт мє ѕυтℓι вσмв fσ∂ ∂υиgα тєяι мαα кι נнααтє נαℓ кє кнααк нσ נαуєgι💣💋",     
      "тєяι ναнєєи кσ нσяℓι¢кѕ ρєєℓαкє ¢нσ∂υиgα мα∂αя¢нσ∂😚",     
      "тєяι ιтєм кι gααи∂ мє ℓυи∂ ∂ααℓкє,тєяє נαιѕα єк σя иιкααℓ ∂υиgα мα∂αя¢нσ∂😆🤤💋",     
      "тєяι ναнєєи кσ αρиє ℓυи∂ ρя ιтиα נнυℓααυиgα кι נнυℓтє נнυℓтє нι вα¢нα ραι∂α кя ∂єgι 💦💋",     
      "ѕυαя кє ριℓℓє тєяι мααкσ ѕα∂αк ρя ℓιтαкє ¢нσ∂ ∂υиgα 😂😆🤤",     
      "αвє тєяι мααкα внσѕ∂α мα∂єя¢нσσ∂ кя ριℓℓє ραρα ѕє ℓα∂єgα тυ 😼😂🤤",     
      "gαℓι gαℓι иє ѕнσя нє тєяι мαα яαи∂ι ¢нσя нє 💋💋💦",     
      "αвє тєяι вєнєи кσ ¢нσ∂υ яαи∂ιкє ριℓℓє кυттє кє ¢нσ∂є 😂👻🔥",     
      "тєяι мααкσ αιѕє ¢нσ∂α αιѕє ¢нσ∂α тєяι мααα вє∂ ρєнι мυтн ∂ια 💦💦💦💦",     
      "тєяι вєнєи кє внσѕ∂є мє αααg ℓαgα∂ια мєяα мσтα ℓυи∂ ∂αℓкє 🔥🔥💦😆😆",     
      "яαи∂ιкє вα¢ннє тєяι мααкσ ¢нσ∂υ ¢нαℓ иιкαℓ",     
      "кιтиα ¢нσ∂υ тєяι яαи∂ι мααкι ¢нυтн αвв αρиι вєнєи кσ внєנ 😆👻🤤",     
      "тєяι вєнєи кσтσ ¢нσ∂ ¢нσ∂кє ρυяα fαα∂ ∂ια ¢нυтн αвв тєяι gf кσ внєנ 😆💦🤤",     
      "тєяι gf кσ єтиα ¢нσ∂α вєнєи кє ℓσ∂є тєяι gf тσ мєяι яαи∂ι вαиgαуι αвв ¢нαℓ тєяι мααкσ ¢нσ∂тα fιяѕє ♥️💦😆😆😆😆",     
      "нαяι нαяι gнααѕ мє נнσρ∂α тєяι мααкα внσѕ∂α 🤣🤣💋💦",     
      "¢нαℓ тєяє вααρ кσ внєנ тєяα вαѕкα инι нє ραρα ѕє ℓα∂єgα тυ",     
      "тєяι вєнєи кι ¢нυтн мє вσмв ∂αℓкє υ∂α ∂υиgα мααкє ℓαω∂є",     
      "тєяι мααкσ тяαιи мє ℓєנαкє тσρ вє∂ ρє ℓιтαкє ¢нσ∂ ∂υиgα ѕυαя кє ριℓℓє 🤣🤣💋💋",     
      "тєяι мαααкє иυ∂єѕ gσσgℓє ρє υρℓσα∂ кαя∂υиgα вєнєи кє ℓαєω∂є 👻🔥",     
      "тєяι мαααкє иυ∂єѕ gσσgℓє ρє υρℓσα∂ кαя∂υиgα вєнєи кє ℓαєω∂є 👻🔥",     
      "тєяι вєнєи кσ ¢нσ∂ ¢нσ∂кє νι∂єσ вαиαкє χиχχ.¢σм ρє иєєℓαм кαя∂υиgα кυттє кє ριℓℓє 💦💋",     
      "тєяι мαααкι ¢нυ∂αι кσ ρσяинυв.¢σм ρє υρℓσα∂ кαя∂υиgα ѕυαя кє ¢нσ∂є 🤣💋💦",     
      "αвє тєяι вєнєи кσ ¢нσ∂υ яαи∂ιкє вα¢ннє тєяєкσ ¢нαккσ ѕє ριℓωανυиgα яαи∂ιкє вα¢ннє 🤣🤣",     
      "тєяι мααкι ¢нυтн fαα∂кє яαк∂ια мααкє ℓσ∂є נαα αвв ѕιℓωαℓє 👄👄",     
      "тєяι вєнєи кι ¢нυтн мє мєяα ℓυи∂ кααℓα",     
      "тєяι вєнєи ℓєтι мєяι ℓυи∂ вα∂є мαѕтι ѕє тєяι вєнєи кσ мєиє ¢нσ∂ ∂αℓα вσнσт ѕαѕтє ѕє",     
      "вєтє тυ вααρ ѕє ℓєgα ραиgα тєяι мααα кσ ¢нσ∂ ∂υиgα кαякє иαиgα 💦💋",     
      "нαнαнαн мєяє вєтє αgℓι вααя αρиι мααкσ ℓєкє ααуα мαтн кαт σя мєяє мσтє ℓυи∂ ѕє ¢нυ∂ωαуα мαтн кαя",   
      "¢нαℓ вєтα тυנнє мααf кια 🤣 αвв αρиι gf кσ внєנ",     
      "ѕнαяαм кαя тєяι вєнєи кα внσѕ∂α кιтиα gααℓια ѕυиωαуєgα αρиι мααα вєнєи кє υρєя",     
      "αвє яαи∂ιкє вα¢ннє αυкαт инι нєтσ αρиι яαи∂ι мααкσ ℓєкє ααуα мαтн кαя нαнαнαнα",     
      "кι∂z мα∂αя¢нσ∂ тєяι мααкσ ¢нσ∂ ¢нσ∂кє тєяя ℓιує внαι ∂є∂ιуα",     
      "נυиgℓє мє иα¢нтα нє мσяє тєяι мααкι ¢нυ∂αι ∂єккє ѕαв вσℓтє σи¢є мσяє σи¢є мσяє 🤣🤣💦💋",     
      "gαℓι gαℓι мє яєнтα нє ѕαи∂ тєяι мααкσ ¢нσ∂ ∂αℓα σя вαиα ∂ια яαи∂ 🤤🤣",     
      "ѕαв вσℓтє мυנнкσ ραρα куσυикι мєиє вαиα∂ια тєяι мααкσ ρяєgиєит 🤣🤣",     
      "ѕυαя кє ριℓℓє тєяι мααкι ¢нυтн мє ѕυαя кα ℓσυ∂α σя тєяι вєнєи кι ¢нυтн мє мєяα ℓσ∂α",     
      "¢нαℓ ¢нαℓ αρиι мααкι ¢нυ¢нιуα ∂ιкα",     
      "нαнαнαнα вα¢ннє тєяι мαααкσ ¢нσ∂ ∂ια иαиgα кαякє",     
      "тєяι gf нє вα∂ι ѕєχу υѕкσ ριℓαкє ¢нσσ∂єиgє ρєρѕι",     
      "2 яυραу кι ρєρѕι тєяι мυмму ѕαвѕє ѕєχу 💋💦",     
      "тєяι мααкσ ¢нєємѕ ѕє ¢нυ∂ωανυиgα мα∂єя¢нσσ∂ кє ριℓℓє 💦🤣",     "тєяι вєнєи кι ¢нυтн мє мυтнкє fαяαя нσנανυиgα нυι нυι нυι",     "ѕρєє∂ ℓααα тєяι вєнєи ¢нσ∂υ яαи∂ιкє ριℓℓє 💋💦🤣",     
      "αяє яє мєяє вєтє куσυи ѕρєє∂ ραкα∂ иα ρααα яαнα αρиє вααρ кα нαнαн🤣🤣",     
      "ѕυи ѕυи ѕυαя кє ριℓℓє נнαитσ кє ѕσυ∂αgαя αρиι мυмму кι иυ∂єѕ внєנ",     
      "αвє ѕυи ℓσ∂є тєяι вєнєи кα внσѕ∂α fαα∂ ∂υиgα",     
      "тєяι мααкσ кнυℓє вαנαя мє ¢нσ∂ ∂αℓα 🤣🤣💋",
     ]
     
     replyraids = [
         "𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝘽𝙃𝙊𝙎𝘿𝙄𝙆𝙀",
    "𝙇𝘼𝘼𝘼𝙒𝙀𝙀𝙀 𝙆𝙀 𝘽𝘼𝘼𝘼𝘼𝘼𝙇",
    "𝙈𝘼𝘼𝘼𝘼𝙍 𝙆𝙄 𝙅𝙃𝘼𝘼𝘼𝘼𝙏 𝙆𝙀 𝘽𝘽𝘽𝘽𝘽𝘼𝘼𝘼𝘼𝘼𝙇𝙇𝙇𝙇𝙇",
    "𝙈𝘼𝘿𝙍𝘾𝙃𝙊𝘿..",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏..",
    "𝙇𝙒𝘿𝙀 𝙆𝙀 𝘽𝘼𝘼𝘼𝙇𝙇𝙇.",
    "𝙈𝘼𝘾𝙃𝘼𝙍 𝙆𝙄 𝙅𝙃𝘼𝘼𝙏 𝙆𝙀 𝘽𝘼𝘼𝘼𝙇𝙇𝙇𝙇",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈 𝘿𝙐 𝙏𝘼𝙋𝘼 𝙏𝘼𝙋?",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝙆𝘼 𝘽𝙃𝙊𝙎𝘿𝘼𝘼",
    "𝙏𝙀𝙍𝙄 𝘽𝙃𝙉 𝙎𝘽𝙎𝘽𝙀 𝘽𝘿𝙄 𝙍𝘼𝙉𝘿𝙄.",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝙊𝙎𝙎𝙀 𝘽𝘼𝘿𝙄 𝙍𝘼𝙉𝘿𝘿𝘿𝘿𝘿",
    "𝙏𝙀𝙍𝘼 𝘽𝘼𝘼𝙋 𝘾𝙃𝙆𝘼𝘼𝘼𝘼",
    "𝙆𝙄𝙏𝙉𝙄 𝘾𝙃𝙊𝘿𝙐 𝙏𝙀𝙍𝙄 𝙈𝘼 𝘼𝘽 𝙊𝙍..",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝘾𝙃𝙊𝘿 𝘿𝙄 𝙃𝙈 𝙉𝙀",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝙆𝙀 𝙎𝙏𝙃 𝙍𝙀𝙀𝙇𝙎 𝘽𝙉𝙀𝙂𝘼 𝙍𝙊𝘼𝘿 𝙋𝙀𝙀",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙀𝙆 𝘿𝘼𝙈 𝙏𝙊𝙋 𝙎𝙀𝙓𝙔",
    "𝙈𝘼𝙇𝙐𝙈 𝙉𝘼 𝙋𝙃𝙍 𝙆𝙀𝙎𝙀 𝙇𝙀𝙏𝘼 𝙃𝙐 𝙈 𝙏𝙀𝙍𝙄 𝙈𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙏𝘼𝙋𝘼 𝙏𝘼𝙋𝙋𝙋𝙋𝙋",
    "𝙇𝙐𝙉𝘿 𝙆𝙀 𝘾𝙃𝙊𝘿𝙀 𝙏𝙐 𝙆𝙀𝙍𝙀𝙂𝘼 𝙏𝙔𝙋𝙄𝙉",
    "𝙎𝙋𝙀𝙀𝘿 𝙋𝙆𝘿 𝙇𝙒𝘿𝙀𝙀𝙀𝙀",
    "𝘽𝘼𝘼𝙋 𝙆𝙄 𝙎𝙋𝙀𝙀𝘿 𝙈𝙏𝘾𝙃 𝙆𝙍𝙍𝙍",
    "𝙇𝙒𝘿𝙀𝙀𝙀",
    "𝙋𝘼𝙋𝘼 𝙆𝙄 𝙎𝙋𝙀𝙀𝘿 𝙈𝙏𝘾𝙃 𝙉𝙃𝙄 𝙃𝙊 𝙍𝙃𝙄 𝙆𝙔𝘼",
    "𝘼𝙇𝙀 𝘼𝙇𝙀 𝙈𝙀𝙇𝘼 𝘽𝘾𝙃𝘼𝘼𝘼𝘼",
    "𝘾𝙃𝙐𝘿 𝙂𝙔𝘼 𝙋𝘼𝙋𝘼 𝙎𝙀𝙀𝙀",
    "𝙆𝙄𝙎𝘼𝙉 𝙆𝙊 𝙆𝙃𝙊𝘿𝙉𝘼 𝙊𝙍",
    "𝙎𝘼𝙇𝙀 𝙍𝘼𝙋𝙀𝙆𝙇 𝙆𝙍𝘿𝙆𝘼 𝙏𝙀𝙍𝘼",
    "𝙃𝘼𝙃𝘼𝙃𝘼𝘼𝘼𝘼𝘼",
    "𝙆𝙄𝘿𝙎𝙎𝙎𝙎",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝘾𝙃𝙐𝘿 𝙂𝙔𝙄 𝘼𝘽 𝙁𝙍𝘼𝙍 𝙈𝙏 𝙃𝙊𝙉𝘼",
    "𝙔𝙀 𝙇𝘿𝙉𝙂𝙀 𝘽𝘼𝙋𝙋 𝙎𝙀",
    "𝙆𝙄𝘿𝙎𝙎𝙎 𝙁𝙍𝘼𝙍 𝙃𝘼𝙃𝘼𝙃𝙃",
    "𝘽𝙃𝙀𝙉 𝙆𝙀 𝙇𝙒𝘿𝙀 𝙎𝙃𝙍𝙈 𝙆𝙍",
    "𝙆𝙄𝙏𝙉𝙄 𝙂𝙇𝙄𝙔𝘼 𝙋𝘿𝙒𝙀𝙂𝘼 𝘼𝙋𝙉𝙄 𝙈𝘼 𝙆𝙊",
    "𝙉𝘼𝙇𝙇𝙀𝙀",
    "𝙎𝙐𝘼𝙍 𝙆𝙀 𝙋𝙄𝙇𝙇𝙀 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝙎𝘼𝘿𝘼𝙆 𝙋𝙍 𝙇𝙄𝙏𝘼𝙆𝙀 𝘾𝙃𝙊𝘿 𝘿𝙐𝙉𝙂𝘼 😂😆🤤",
    "𝘼𝘽𝙀 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝘼 𝘽𝙃𝙊𝙎𝘿𝘼 𝙈𝘼𝘿𝙀𝙍𝘾𝙃𝙊𝙊𝘿 𝙆𝙍 𝙋𝙄𝙇𝙇𝙀 𝙋𝘼𝙋𝘼 𝙎𝙀 𝙇𝘼𝘿𝙀𝙂𝘼 𝙏𝙐 😼😂🤤",
    "𝙂𝘼𝙇𝙄 𝙂𝘼𝙇𝙄 𝙉𝙀 𝙎𝙃𝙊𝙍 𝙃𝙀 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙍𝘼𝙉𝘿𝙄 𝘾𝙃𝙊𝙍 𝙃𝙀 💋💋💦",
    "𝘼𝘽𝙀 𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙊 𝘾𝙃𝙊𝘿𝙐 𝙍𝘼𝙉𝘿𝙄𝙆𝙀 𝙋𝙄𝙇𝙇𝙀 𝙆𝙐𝙏𝙏𝙀 𝙆𝙀 𝘾𝙃𝙊𝘿𝙀 😂👻🔥",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝘼𝙄𝙎𝙀 𝘾𝙃𝙊𝘿𝘼 𝘼𝙄𝙎𝙀 𝘾𝙃𝙊𝘿𝘼 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝘽𝙀𝘿 𝙋𝙀𝙃𝙄 𝙈𝙐𝙏𝙃 𝘿𝙄𝘼 💦💦💦💦",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙀 𝘽𝙃𝙊𝙎𝘿𝙀 𝙈𝙀 𝘼𝘼𝘼𝙂 𝙇𝘼𝙂𝘼𝘿𝙄𝘼 𝙈𝙀𝙍𝘼 𝙈𝙊𝙏𝘼 𝙇𝙐𝙉𝘿 𝘿𝘼𝙇𝙆𝙀 🔥🔥💦😆😆",
    "𝙍𝘼𝙉𝘿𝙄𝙆𝙀 𝘽𝘼𝘾𝙃𝙃𝙀 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝘾𝙃𝙊𝘿𝙐 𝘾𝙃𝘼𝙇 𝙉𝙄𝙆𝘼𝙇",
    "𝙆𝙄𝙏𝙉𝘼 𝘾𝙃𝙊𝘿𝙐 𝙏𝙀𝙍𝙄 𝙍𝘼𝙉𝘿𝙄 𝙈𝘼𝘼𝙆𝙄 𝘾𝙃𝙐𝙏𝙃 𝘼𝘽𝘽 𝘼𝙋𝙉𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙊 𝘽𝙃𝙀𝙅 😆👻🤤",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙊𝙏𝙊 𝘾𝙃𝙊𝘿 𝘾𝙃𝙊𝘿𝙆𝙀 𝙋𝙐𝙍𝘼 𝙁𝘼𝘼𝘿 𝘿𝙄𝘼 𝘾𝙃𝙐𝙏𝙃 𝘼𝘽𝘽 𝙏𝙀𝙍𝙄 𝙂𝙁 𝙆𝙊 𝘽𝙃𝙀𝙅 😆💦🤤",
    "𝙏𝙀𝙍𝙄 𝙂𝙁 𝙆𝙊 𝙀𝙏𝙉𝘼 𝘾𝙃𝙊𝘿𝘼 𝘽𝙀𝙃𝙀𝙉 𝙆𝙀 𝙇𝙊𝘿𝙀 𝙏𝙀𝙍𝙄 𝙂𝙁 𝙏𝙊 𝙈𝙀𝙍𝙄 𝙍𝘼𝙉𝘿𝙄 𝘽𝘼𝙉𝙂𝘼𝙔𝙄 𝘼𝘽𝘽 𝘾𝙃𝘼𝙇 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝘾𝙃𝙊𝘿𝙏𝘼 𝙁𝙄𝙍𝙎𝙀 ♥️💦😆😆😆😆",
    "𝙃𝘼𝙍𝙄 𝙃𝘼𝙍𝙄 𝙂𝙃𝘼𝘼𝙎 𝙈𝙀 𝙅𝙃𝙊𝙋𝘿𝘼 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝘼 𝘽𝙃𝙊𝙎𝘿𝘼 🤣🤣💋💦",
    "𝘾𝙃𝘼𝙇 𝙏𝙀𝙍𝙀 𝘽𝘼𝘼𝙋 𝙆𝙊 𝘽𝙃𝙀𝙅 𝙏𝙀𝙍𝘼 𝘽𝘼𝙎𝙆𝘼 𝙉𝙃𝙄 𝙃𝙀 𝙋𝘼𝙋𝘼 𝙎𝙀 𝙇𝘼𝘿𝙀𝙂𝘼 𝙏𝙐",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙄 𝘾𝙃𝙐𝙏𝙃 𝙈𝙀 𝘽𝙊𝙈𝘽 𝘿𝘼𝙇𝙆𝙀 𝙐𝘿𝘼 𝘿𝙐𝙉𝙂𝘼 𝙈𝘼𝘼𝙆𝙀 𝙇𝘼𝙒𝘿𝙀",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝙏𝙍𝘼𝙄𝙉 𝙈𝙀 𝙇𝙀𝙅𝘼𝙆𝙀 𝙏𝙊𝙋 𝘽𝙀𝘿 𝙋𝙀 𝙇𝙄𝙏𝘼𝙆𝙀 𝘾𝙃𝙊𝘿 𝘿𝙐𝙉𝙂𝘼 𝙎𝙐𝘼𝙍 𝙆𝙀 𝙋𝙄𝙇𝙇𝙀 🤣🤣💋💋",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼𝙆𝙀 𝙉𝙐𝘿𝙀𝙎 𝙂𝙊𝙊𝙂𝙇𝙀 𝙋𝙀 𝙐𝙋𝙇𝙊𝘼𝘿 𝙆𝘼𝙍𝘿𝙐𝙉𝙂𝘼 𝘽𝙀𝙃𝙀𝙉 𝙆𝙀 𝙇𝘼𝙀𝙒𝘿𝙀 👻🔥",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼𝙆𝙀 𝙉𝙐𝘿𝙀𝙎 𝙂𝙊𝙊𝙂𝙇𝙀 𝙋𝙀 𝙐𝙋𝙇𝙊𝘼𝘿 𝙆𝘼𝙍𝘿𝙐𝙉𝙂𝘼 𝘽𝙀𝙃𝙀𝙉 𝙆𝙀 𝙇𝘼𝙀𝙒𝘿𝙀 👻🔥",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙊 𝘾𝙃𝙊𝘿 𝘾𝙃𝙊𝘿𝙆𝙀 𝙑𝙄𝘿𝙀𝙊 𝘽𝘼𝙉𝘼𝙆𝙀 𝙓𝙉𝙓𝙓.𝘾𝙊𝙈 𝙋𝙀 𝙉𝙀𝙀𝙇𝘼𝙈 𝙆𝘼𝙍𝘿𝙐𝙉𝙂𝘼 𝙆𝙐𝙏𝙏𝙀 𝙆𝙀 𝙋𝙄𝙇𝙇𝙀 💦💋",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼𝙆𝙄 𝘾𝙃𝙐𝘿𝘼𝙄 𝙆𝙊 𝙋𝙊𝙍𝙉𝙃𝙐𝘽.𝘾𝙊𝙈 𝙋𝙀 𝙐𝙋𝙇𝙊𝘼𝘿 𝙆𝘼𝙍𝘿𝙐𝙉𝙂𝘼 𝙎𝙐𝘼𝙍 𝙆𝙀 𝘾𝙃𝙊𝘿𝙀 🤣💋💦",
    "𝘼𝘽𝙀 𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙊 𝘾𝙃𝙊𝘿𝙐 𝙍𝘼𝙉𝘿𝙄𝙆𝙀 𝘽𝘼𝘾𝙃𝙃𝙀 𝙏𝙀𝙍𝙀𝙆𝙊 𝘾𝙃𝘼𝙆𝙆𝙊 𝙎𝙀 𝙋𝙄𝙇𝙒𝘼𝙑𝙐𝙉𝙂𝘼 𝙍𝘼𝙉𝘿𝙄𝙆𝙀 𝘽𝘼𝘾𝙃𝙃𝙀 🤣🤣",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙄 𝘾𝙃𝙐𝙏𝙃 𝙁𝘼𝘼𝘿𝙆𝙀 𝙍𝘼𝙆𝘿𝙄𝘼 𝙈𝘼𝘼𝙆𝙀 𝙇𝙊𝘿𝙀 𝙅𝘼𝘼 𝘼𝘽𝘽 𝙎𝙄𝙇𝙒𝘼𝙇𝙀 👄👄",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙄 𝘾𝙃𝙐𝙏𝙃 𝙈𝙀 𝙈𝙀𝙍𝘼 𝙇𝙐𝙉𝘿 𝙆𝘼𝘼𝙇𝘼",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙇𝙀𝙏𝙄 𝙈𝙀𝙍𝙄 𝙇𝙐𝙉𝘿 𝘽𝘼𝘿𝙀 𝙈𝘼𝙎𝙏𝙄 𝙎𝙀 𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙊 𝙈𝙀𝙉𝙀 𝘾𝙃𝙊𝘿 𝘿𝘼𝙇𝘼 𝘽𝙊𝙃𝙊𝙏 𝙎𝘼𝙎𝙏𝙀 𝙎𝙀",
    "𝘽𝙀𝙏𝙀 𝙏𝙐 𝘽𝘼𝘼𝙋 𝙎𝙀 𝙇𝙀𝙂𝘼 𝙋𝘼𝙉𝙂𝘼 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙆𝙊 𝘾𝙃𝙊𝘿 𝘿𝙐𝙉𝙂𝘼 𝙆𝘼𝙍𝙆𝙀 𝙉𝘼𝙉𝙂𝘼 💦💋",
    "𝙃𝘼𝙃𝘼𝙃𝘼𝙃 𝙈𝙀𝙍𝙀 𝘽𝙀𝙏𝙀 𝘼𝙂𝙇𝙄 𝘽𝘼𝘼𝙍 𝘼𝙋𝙉𝙄 𝙈𝘼𝘼𝙆𝙊 𝙇𝙀𝙆𝙀 𝘼𝘼𝙔𝘼 𝙈𝘼𝙏𝙃 𝙆𝘼𝙏 𝙊𝙍 𝙈𝙀𝙍𝙀 𝙈𝙊𝙏𝙀 𝙇𝙐𝙉𝘿 𝙎𝙀 𝘾𝙃𝙐𝘿𝙒𝘼𝙔𝘼 𝙈𝘼𝙏𝙃 𝙆𝘼𝙍",
    "𝘾𝙃𝘼𝙇 𝘽𝙀𝙏𝘼 𝙏𝙐𝙅𝙃𝙀 𝙈𝘼𝘼𝙁 𝙆𝙄𝘼 🤣 𝘼𝘽𝘽 𝘼𝙋𝙉𝙄 𝙂𝙁 𝙆𝙊 𝘽𝙃𝙀𝙅",
    "𝙎𝙃𝘼𝙍𝘼𝙈 𝙆𝘼𝙍 𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝘼 𝘽𝙃𝙊𝙎𝘿𝘼 𝙆𝙄𝙏𝙉𝘼 𝙂𝘼𝘼𝙇𝙄𝘼 𝙎𝙐𝙉𝙒𝘼𝙔𝙀𝙂𝘼 𝘼𝙋𝙉𝙄 𝙈𝘼𝘼𝘼 𝘽𝙀𝙃𝙀𝙉 𝙆𝙀 𝙐𝙋𝙀𝙍",
    "𝘼𝘽𝙀 𝙍𝘼𝙉𝘿𝙄𝙆𝙀 𝘽𝘼𝘾𝙃𝙃𝙀 𝘼𝙐𝙆𝘼𝙏 𝙉𝙃𝙄 𝙃𝙀𝙏𝙊 𝘼𝙋𝙉𝙄 𝙍𝘼𝙉𝘿𝙄 𝙈𝘼𝘼𝙆𝙊 𝙇𝙀𝙆𝙀 𝘼𝘼𝙔𝘼 𝙈𝘼𝙏𝙃 𝙆𝘼𝙍 𝙃𝘼𝙃𝘼𝙃𝘼𝙃𝘼",
    "𝙆𝙄𝘿𝙕 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝘾𝙃𝙊𝘿 𝘾𝙃𝙊𝘿𝙆𝙀 𝙏𝙀𝙍𝙍 𝙇𝙄𝙔𝙀 𝘽𝙃𝘼𝙄 𝘿𝙀𝘿𝙄𝙔𝘼",
    "𝙅𝙐𝙉𝙂𝙇𝙀 𝙈𝙀 𝙉𝘼𝘾𝙃𝙏𝘼 𝙃𝙀 𝙈𝙊𝙍𝙀 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙄 𝘾𝙃𝙐𝘿𝘼𝙄 𝘿𝙀𝙆𝙆𝙀 𝙎𝘼𝘽 𝘽𝙊𝙇𝙏𝙀 𝙊𝙉𝘾𝙀 𝙈𝙊𝙍𝙀 𝙊𝙉𝘾𝙀 𝙈𝙊𝙍𝙀 🤣🤣💦💋",
    "𝙂𝘼𝙇𝙄 𝙂𝘼𝙇𝙄 𝙈𝙀 𝙍𝙀𝙃𝙏𝘼 𝙃𝙀 𝙎𝘼𝙉𝘿 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝘾𝙃𝙊𝘿 𝘿𝘼𝙇𝘼 𝙊𝙍 𝘽𝘼𝙉𝘼 𝘿𝙄𝘼 𝙍𝘼𝙉𝘿 🤤🤣",
    "𝙎𝘼𝘽 𝘽𝙊𝙇𝙏𝙀 𝙈𝙐𝙅𝙃𝙆𝙊 𝙋𝘼𝙋𝘼 𝙆𝙔𝙊𝙐𝙉𝙆𝙄 𝙈𝙀𝙉𝙀 𝘽𝘼𝙉𝘼𝘿𝙄𝘼 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝙋𝙍𝙀𝙂𝙉𝙀𝙉𝙏 🤣🤣",
    "𝙎𝙐𝘼𝙍 𝙆𝙀 𝙋𝙄𝙇𝙇𝙀 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙄 𝘾𝙃𝙐𝙏𝙃 𝙈𝙀 𝙎𝙐𝘼𝙍 𝙆𝘼 𝙇𝙊𝙐𝘿𝘼 𝙊𝙍 𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙄 𝘾𝙃𝙐𝙏𝙃 𝙈𝙀 𝙈𝙀𝙍𝘼 𝙇𝙊𝘿𝘼",
    "𝘾𝙃𝘼𝙇 𝘾𝙃𝘼𝙇 𝘼𝙋𝙉𝙄 𝙈𝘼𝘼𝙆𝙄 𝘾𝙃𝙐𝘾𝙃𝙄𝙔𝘼 𝘿𝙄𝙆𝘼",
    "𝙃𝘼𝙃𝘼𝙃𝘼𝙃𝘼 𝘽𝘼𝘾𝙃𝙃𝙀 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼𝙆𝙊 𝘾𝙃𝙊𝘿 𝘿𝙄𝘼 𝙉𝘼𝙉𝙂𝘼 𝙆𝘼𝙍𝙆𝙀",
    "𝙏𝙀𝙍𝙄 𝙂𝙁 𝙃𝙀 𝘽𝘼𝘿𝙄 𝙎𝙀𝙓𝙔 𝙐𝙎𝙆𝙊 𝙋𝙄𝙇𝘼𝙆𝙀 𝘾𝙃𝙊𝙊𝘿𝙀𝙉𝙂𝙀 𝙋𝙀𝙋𝙎𝙄",
    "2 𝙍𝙐𝙋𝘼𝙔 𝙆𝙄 𝙋𝙀𝙋𝙎𝙄 𝙏𝙀𝙍𝙄 𝙈𝙐𝙈𝙈𝙔 𝙎𝘼𝘽𝙎𝙀 𝙎𝙀𝙓𝙔 💋💦",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝘾𝙃𝙀𝙀𝙈𝙎 𝙎𝙀 𝘾𝙃𝙐𝘿𝙒𝘼𝙑𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝙀𝙍𝘾𝙃𝙊𝙊𝘿 𝙆𝙀 𝙋𝙄𝙇𝙇𝙀 💦🤣",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝙄 𝘾𝙃𝙐𝙏𝙃 𝙈𝙀 𝙈𝙐𝙏𝙃𝙆𝙀 𝙁𝘼𝙍𝘼𝙍 𝙃𝙊𝙅𝘼𝙑𝙐𝙉𝙂𝘼 𝙃𝙐𝙄 𝙃𝙐𝙄 𝙃𝙐𝙄",
    "𝙎𝙋𝙀𝙀𝘿 𝙇𝘼𝘼𝘼 𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝘾𝙃𝙊𝘿𝙐 𝙍𝘼𝙉𝘿𝙄𝙆𝙀 𝙋𝙄𝙇𝙇𝙀 💋💦🤣",
    "𝘼𝙍𝙀 𝙍𝙀 𝙈𝙀𝙍𝙀 𝘽𝙀𝙏𝙀 𝙆𝙔𝙊𝙐𝙉 𝙎𝙋𝙀𝙀𝘿 𝙋𝘼𝙆𝘼𝘿 𝙉𝘼 𝙋𝘼𝘼𝘼 𝙍𝘼𝙃𝘼 𝘼𝙋𝙉𝙀 𝘽𝘼𝘼𝙋 𝙆𝘼 𝙃𝘼𝙃𝘼𝙃🤣🤣",
    "𝙎𝙐𝙉 𝙎𝙐𝙉 𝙎𝙐𝘼𝙍 𝙆𝙀 𝙋𝙄𝙇𝙇𝙀 𝙅𝙃𝘼𝙉𝙏𝙊 𝙆𝙀 𝙎𝙊𝙐𝘿𝘼𝙂𝘼𝙍 𝘼𝙋𝙉𝙄 𝙈𝙐𝙈𝙈𝙔 𝙆𝙄 𝙉𝙐𝘿𝙀𝙎 𝘽𝙃𝙀𝙅",
    "𝘼𝘽𝙀 𝙎𝙐𝙉 𝙇𝙊𝘿𝙀 𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙆𝘼 𝘽𝙃𝙊𝙎𝘿𝘼 𝙁𝘼𝘼𝘿 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝙆𝙊 𝙆𝙃𝙐𝙇𝙀 𝘽𝘼𝙅𝘼𝙍 𝙈𝙀 𝘾𝙃𝙊𝘿 𝘿𝘼𝙇𝘼 🤣🤣💋",
    "𝙎𝙃𝙍𝙈 𝙆𝙍",
    "𝙈𝙀𝙍𝙀 𝙇𝙐𝙉𝘿 𝙆𝙀 𝘽𝘼𝘼𝘼𝘼𝘼𝙇𝙇𝙇𝙇𝙇",
    "𝙆𝙄𝙏𝙉𝙄 𝙂𝙇𝙄𝙔𝘼 𝙋𝘿𝙒𝙔𝙂𝘼 𝘼𝙋𝙉𝙄 𝙈𝘼 𝘽𝙃𝙀𝙉 𝙆𝙊",
    "𝙍𝙉𝘿𝙄 𝙆𝙀 𝙇𝘿𝙆𝙀𝙀𝙀𝙀𝙀𝙀𝙀𝙀𝙀",
    "𝙆𝙄𝘿𝙎𝙎𝙎𝙎𝙎𝙎𝙎𝙎𝙎𝙎𝙎𝙎",
    "𝘼𝙥𝙣𝙞 𝙜𝙖𝙖𝙣𝙙 𝙢𝙚𝙞𝙣 𝙢𝙪𝙩𝙝𝙞 𝙙𝙖𝙖𝙡",
    "𝘼𝙥𝙣𝙞 𝙡𝙪𝙣𝙙 𝙘𝙝𝙤𝙤𝙨",
    "𝘼𝙥𝙣𝙞 𝙢𝙖 𝙠𝙤 𝙟𝙖 𝙘𝙝𝙤𝙤𝙨",
    "𝘽𝙝𝙚𝙣 𝙠𝙚 𝙡𝙖𝙪𝙙𝙚",
    "𝘽𝙝𝙚𝙣 𝙠𝙚 𝙩𝙖𝙠𝙠𝙚",
    "𝘼𝙗𝙡𝙖 𝙏𝙀𝙍𝘼 𝙆𝙃𝘼𝙉 𝘿𝘼𝙉 𝘾𝙃𝙊𝘿𝙉𝙀 𝙆𝙄 𝘽𝘼𝙍𝙄𝙄𝙄",
    "𝘽𝙀𝙏𝙀 𝙏𝙀𝙍𝙄 𝙈𝘼 𝙎𝘽𝙎𝙀 𝘽𝘿𝙄 𝙍𝘼𝙉𝘿",
    "𝙇𝙐𝙉𝘿 𝙆𝙀 𝘽𝘼𝘼𝘼𝙇 𝙅𝙃𝘼𝙏 𝙆𝙀 𝙋𝙄𝙎𝙎𝙎𝙐𝙐𝙐𝙐𝙐𝙐𝙐",
    "𝙇𝙐𝙉𝘿 𝙋𝙀 𝙇𝙏𝙆𝙄𝙏 𝙈𝘼𝘼𝘼𝙇𝙇𝙇𝙇 𝙆𝙄 𝘽𝙊𝙉𝘿 𝙃 𝙏𝙐𝙐𝙐",
    "𝙆𝘼𝙎𝙃 𝙊𝙎 𝘿𝙄𝙉 𝙈𝙐𝙏𝙃 𝙈𝙍𝙆𝙀 𝙎𝙊𝙅𝙏𝘼 𝙈 𝙏𝙐𝙉 𝙋𝘼𝙄𝘿𝘼 𝙉𝘼 𝙃𝙊𝙏𝘼𝘼",
    "𝙂𝙇𝙏𝙄 𝙆𝙍𝘿𝙄 𝙏𝙐𝙅𝙒 𝙋𝘼𝙄𝘿𝘼 𝙆𝙍𝙆𝙀",
    "𝙎𝙋𝙀𝙀𝘿 𝙋𝙆𝘿𝘿𝘿",
    "𝙂𝙖𝙖𝙣𝙙 𝙢𝙖𝙞𝙣 𝙇𝙒𝘿𝘼 𝘿𝘼𝙇 𝙇𝙀 𝘼𝙋𝙉𝙄 𝙈𝙀𝙍𝘼𝘼𝘼",
    "𝙂𝙖𝙖𝙣𝙙 𝙢𝙚𝙞𝙣 𝙗𝙖𝙢𝙗𝙪 𝘿𝙀𝘿𝙐𝙉𝙂𝘼𝘼𝘼𝘼𝘼𝘼",
    "𝙂𝘼𝙉𝘿 𝙁𝙏𝙄 𝙆𝙀 𝘽𝘼𝙇𝙆𝙆𝙆",
    "𝙂𝙤𝙩𝙚 𝙠𝙞𝙩𝙣𝙚 𝙗𝙝𝙞 𝙗𝙖𝙙𝙚 𝙝𝙤, 𝙡𝙪𝙣𝙙 𝙠𝙚 𝙣𝙞𝙘𝙝𝙚 𝙝𝙞 𝙧𝙚𝙝𝙩𝙚 𝙝𝙖𝙞",
    "𝙃𝙖𝙯𝙖𝙖𝙧 𝙡𝙪𝙣𝙙 𝙩𝙚𝙧𝙞 𝙜𝙖𝙖𝙣𝙙 𝙢𝙖𝙞𝙣",
    "𝙅𝙝𝙖𝙖𝙣𝙩 𝙠𝙚 𝙥𝙞𝙨𝙨𝙪-",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝙆𝙄 𝙆𝘼𝙇𝙄 𝘾𝙃𝙐𝙏",
    "𝙆𝙝𝙤𝙩𝙚𝙮 𝙠𝙞 𝙖𝙪𝙡𝙙𝙖",
    "𝙆𝙪𝙩𝙩𝙚 𝙠𝙖 𝙖𝙬𝙡𝙖𝙩",
    "𝙆𝙪𝙩𝙩𝙚 𝙠𝙞 𝙟𝙖𝙩",
    "𝙆𝙪𝙩𝙩𝙚 𝙠𝙚 𝙩𝙖𝙩𝙩𝙚",
    "𝙏𝙀𝙏𝙄 𝙈𝘼 𝙆𝙄.𝘾𝙃𝙐𝙏 , 𝙩𝙀𝙍𝙄 𝙈𝘼 𝙍𝙉𝘿𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄",
    "𝙇𝙖𝙫𝙙𝙚 𝙠𝙚 𝙗𝙖𝙡",
    "𝙢𝙪𝙝 𝙢𝙚𝙞 𝙡𝙚𝙡𝙚",
    "𝙇𝙪𝙣𝙙 𝙆𝙚 𝙋𝙖𝙨𝙞𝙣𝙚",
    "𝙈𝙀𝙍𝙀 𝙇𝙒𝘿𝙀 𝙆𝙀 𝘽𝘼𝘼𝘼𝘼𝘼𝙇𝙇𝙇",
    "𝙃𝘼𝙃𝘼𝙃𝘼𝘼𝘼𝘼𝘼𝘼",
    "𝘾𝙃𝙐𝘿 𝙂𝙔𝘼𝘼𝘼𝘼𝘼",
    "𝙍𝙖𝙣𝙙𝙞 𝙠𝙝𝙖𝙣𝙀 𝙆𝙄 𝙐𝙇𝘼𝘿𝘿𝘿",
    "𝙎𝙖𝙙𝙞 𝙝𝙪𝙞 𝙜𝙖𝙖𝙣𝙙",
    "𝙏𝙚𝙧𝙞 𝙜𝙖𝙖𝙣𝙙 𝙢𝙖𝙞𝙣 𝙠𝙪𝙩𝙚 𝙠𝙖 𝙡𝙪𝙣𝙙",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙠𝙖 𝙗𝙝𝙤𝙨𝙙𝙖",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙠𝙞 𝙘𝙝𝙪𝙩",
    "𝙏𝙚𝙧𝙚 𝙜𝙖𝙖𝙣𝙙 𝙢𝙚𝙞𝙣 𝙠𝙚𝙚𝙙𝙚 𝙥𝙖𝙙𝙖𝙮",
    "𝙐𝙡𝙡𝙪 𝙠𝙚 𝙥𝙖𝙩𝙝𝙚",
    "𝙎𝙐𝙉𝙉 𝙈𝘼𝘿𝙀𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼 𝘽𝙃𝙊𝙎𝘿𝘼",
    "𝘽𝙀𝙃𝙀𝙉 𝙆 𝙇𝙐𝙉𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼 𝘾𝙃𝙐𝙏 𝙆𝙄 𝘾𝙃𝙏𝙉𝙄𝙄𝙄𝙄",
    "𝙈𝙀𝙍𝘼 𝙇𝘼𝙒𝘿𝘼 𝙇𝙀𝙇𝙀 𝙏𝙐 𝘼𝙂𝘼𝙍 𝘾𝙃𝘼𝙄𝙔𝙀 𝙏𝙊𝙃",
    "𝙂𝘼𝘼𝙉𝘿𝙐",
    "𝘾𝙃𝙐𝙏𝙄𝙔𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙋𝙀 𝙅𝘾𝘽 𝘾𝙃𝘼𝘿𝙃𝘼𝘼 𝘿𝙐𝙉𝙂𝘼",
    "𝙎𝘼𝙈𝙅𝙃𝘼𝘼 𝙇𝘼𝙒𝘿𝙀",
    "𝙔𝘼 𝘿𝙐 𝙏𝙀𝙍𝙀 𝙂𝘼𝘼𝙉𝘿 𝙈𝙀 𝙏𝘼𝙋𝘼𝘼 𝙏𝘼𝙋��",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙈𝙀𝙍𝘼 𝙍𝙊𝙕 𝙇𝙀𝙏𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙂𝙁 𝙆 𝙎𝘼𝘼𝙏𝙃 𝙈𝙈𝙎 𝘽𝘼𝙉𝘼𝘼 𝘾𝙃𝙐𝙆𝘼 𝙃𝙐���不�不",
    "𝙏𝙐 𝘾𝙃𝙐𝙏𝙄𝙔𝘼 𝙏𝙀𝙍𝘼 𝙆𝙃𝘼𝙉𝘿𝘼𝘼𝙉 𝘾𝙃𝙐𝙏𝙄𝙔𝘼",
    "𝘼𝙐𝙍 𝙆𝙄𝙏𝙉𝘼 𝘽𝙊𝙇𝙐 𝘽𝙀𝙔 𝙈𝘼𝙉𝙉 𝘽𝙃𝘼𝙍 𝙂𝘼𝙔𝘼 𝙈𝙀𝙍𝘼�不",
    "𝙏𝙀𝙍𝙄𝙄𝙄𝙄𝙄𝙄 𝙈𝘼𝘼𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏𝙏𝙏 𝙈𝙀 𝘼𝘽𝘾𝘿 𝙇𝙄𝙆𝙃 𝘿𝙐𝙉𝙂𝘼 𝙈𝘼𝘼 𝙆𝙀 𝙇𝙊𝘿𝙀",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝙇𝙀𝙆𝘼𝙍 𝙈𝘼𝙄 𝙁𝘼𝙍𝘼𝙍",
    "𝙍𝘼𝙉𝙄𝘿𝙄𝙄𝙄",
    "𝘽𝘼𝘾𝙃𝙀𝙀",
    "𝘾𝙃𝙊𝘿𝙐",
    "𝙍𝘼𝙉𝘿𝙄",
    "𝙍𝘼𝙉𝘿𝙄 𝙆𝙀 𝙋𝙄𝙇𝙇𝙀",
    "𝙏𝙀𝙍𝙄𝙄𝙄𝙄𝙄 𝙈𝘼𝘼𝘼 𝙆𝙊 𝘽𝙃𝙀𝙅𝙅𝙅",
    "𝙏𝙀𝙍𝘼𝘼 𝘽𝘼𝘼𝘼𝘼𝙋 𝙃𝙐",
    "𝙩𝙚𝙧𝙞 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙃𝘼𝘼𝙏 𝘿𝘼𝘼𝙇𝙇𝙆𝙀 𝘽𝙃𝘼𝘼𝙂 𝙅𝘼𝘼𝙉𝙐𝙂𝘼",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙆𝙊 𝙎𝘼𝙍𝘼𝙆 𝙋𝙀 𝙇𝙀𝙏𝘼𝘼 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝙂𝘽 𝙍𝙊𝘼𝘿 𝙋𝙀 𝙇𝙀𝙅𝘼𝙆𝙀 𝘽𝙀𝘾𝙃 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀́ 𝙆𝘼𝘼𝙇𝙄 𝙈𝙄𝙏𝘾𝙃",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙎𝘼𝙎𝙏𝙄 𝙍𝘼𝙉𝘿𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙆𝘼𝘽𝙐𝙏𝘼𝙍 𝘿𝘼𝘼𝙇 𝙆𝙀 𝙎𝙊𝙐𝙋 𝘽𝘼𝙉𝘼𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙍𝘼𝙉𝘿𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝘿𝙀𝙏𝙊𝙇 𝘿𝘼𝘼𝙇 𝘿𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼𝘼𝘼 𝘽𝙃𝙊𝙎𝘿𝘼𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙇𝘼𝙋𝙏𝙊𝙋",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙍𝘼𝙉𝘿𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝘽𝙄𝙎𝙏𝘼𝙍 𝙋𝙀 𝙇𝙀𝙏𝘼𝘼𝙆𝙀 𝘾𝙃𝙊𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝘼𝙈𝙀𝙍𝙄𝘾𝘼 𝙂𝙃𝙐𝙈𝘼𝘼𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙉𝘼𝘼𝙍𝙄𝙔𝘼𝙇 𝙋𝙃𝙊𝙍 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙀 𝙂𝘼𝙉𝘿 𝙈𝙀 𝘿𝙀𝙏𝙊𝙇 𝘿𝘼𝘼𝙇 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙆𝙊 𝙃𝙊𝙍𝙇𝙄𝘾𝙆𝙎 𝙋𝙄𝙇𝘼𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝙎𝘼𝙍𝘼𝙆 𝙋𝙀 𝙇𝙀𝙏𝘼𝘼𝘼 𝘿𝙐𝙉𝙂𝘼𝘼𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼𝘼 𝘽𝙃𝙊𝙎𝘿𝘼",
    "𝙈𝙀𝙍𝘼𝘼𝘼 𝙇𝙐𝙉𝘿 𝙋𝘼𝙆𝘼𝘿 𝙇𝙀 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝘾𝙃𝙐𝙋 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝘼𝙆𝘼𝘼 𝘽𝙃𝙊𝙎𝘿𝘼𝘼",
    "𝙏𝙀𝙍𝙄𝙄𝙄 𝙈𝘼𝘼 𝘾𝙃𝙐𝙁 𝙂𝙀𝙔𝙄𝙄 𝙆𝙔𝘼𝘼𝘼 𝙇𝘼𝙒𝘿𝙀𝙀𝙀",
    "𝙏𝙀𝙍𝙄𝙄𝙄 𝙈𝘼𝘼 𝙆𝘼𝘼 𝘽𝙅𝙎𝙊𝘿𝘼𝘼𝘼",
    "𝙈𝘼𝘿𝘼𝙍𝙓𝙃𝙊𝘿𝘿𝘿",
    "𝙏𝙀𝙍𝙄𝙐𝙐𝙄 𝙈𝘼𝘼𝘼 𝙆𝘼𝘼 𝘽𝙃𝙎𝙊𝘿𝘼𝘼𝘼",
    "𝙏𝙀𝙍𝙄𝙄𝙄𝙄𝙄𝙄 𝘽𝙀𝙃𝙀𝙉𝙉𝙉𝙉 𝙆𝙊 𝘾𝙃𝙊𝘿𝘿𝘿𝙐𝙐𝙐𝙐 𝙈𝘼𝘿𝘼𝙍𝙓𝙃𝙊𝘿𝘿𝘿𝘿",
    "𝙉𝙄𝙆𝘼𝙇 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙍𝘼𝙉𝘿𝙄 𝙆𝙀 𝘽𝘼𝘾𝙃𝙀",
    "𝙏𝙀𝙍𝘼 𝙈𝘼𝘼 𝙈𝙀𝙍𝙄 𝙁𝘼𝙉",
    "𝙏𝙀𝙍𝙄 𝙎𝙀𝙓𝙔 𝘽𝘼𝙃𝙀𝙉 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙊𝙋",
    ]

plinks = [
        "https://telegra.ph/file/9bcc076fd81dfe3feb291.mp4",
        "https://telegra.ph/file/b7a1a42429a65f64e67af.mp4",
        "https://telegra.ph/file/dc3da5a3eb77ae20fa21d.mp4",
        "https://telegra.ph/file/22b89774a4ba9219d530b.mp4",
        "https://telegra.ph/file/7b15fbca08ae1e73e559c.mp4",
        "https://telegra.ph/file/a9c1dea3f34925bb60686.mp4",
        "https://telegra.ph/file/913b4e567b7f435b7f0db.mp4",
        "https://telegra.ph/file/5a5d1a919a97af2314955.mp4",
        "https://telegra.ph/file/0f8b903669600d304cbe4.mp4",
        "https://telegra.ph/file/f3816b54c9eb7617356b6.mp4",
        "https://telegra.ph/file/516dbaa03fde1aaa70633.mp4",
        "https://telegra.ph/file/07bba6ead0f1e381b1bd1.mp4",
        "https://telegra.ph/file/0a4f7935df9b4ab8d62ed.mp4",
        "https://telegra.ph/file/40966bf68c0e4dbe18058.mp4",
        "https://telegra.ph/file/50637aa9c04d136687523.mp4",
        "https://telegra.ph/file/b81c0b0e491da73e64260.mp4",
        "https://telegra.ph/file/4ddf5f29783d92ae03804.mp4",
        "https://telegra.ph/file/4037dc2517b702cc208b1.mp4",
        "https://telegra.ph/file/33cebe2798c15d52a2547.mp4",
        "https://telegra.ph/file/4dc3c8b03616da516104a.mp4",
        "https://telegra.ph/file/6b148dace4d987fae8f3e.mp4",
        "https://telegra.ph/file/8cb081db4eeed88767635.mp4",
        "https://telegra.ph/file/98d3eb94e6f00ed56ef91.mp4",
        "https://telegra.ph/file/1fb387cf99e057b62d75d.mp4",
        "https://telegra.ph/file/6e1161f63879c07a1f213.mp4",
        "https://telegra.ph/file/0bf4defb9540d2fa6d277.mp4",
        "https://telegra.ph/file/d5f8280754d9aa5dffa6a.mp4",
        "https://telegra.ph/file/0f23807ed1930704e2bef.jpg",
        "https://telegra.ph/file/c49280b8f1dcecaf86c00.jpg",
        "https://telegra.ph/file/f483400ff141de73767ca.jpg",
        "https://telegra.ph/file/1543bbea4e3c1abb6764a.jpg",
        "https://telegra.ph/file/a0d77be0d769c7cd334ab.jpg",
        "https://telegra.ph/file/6c6e93860527d2f577df8.jpg",
        "https://telegra.ph/file/d987b0e72eb3bb4801f01.jpg",
        "https://telegra.ph/file/b434999287d3580250960.jpg",
        "https://telegra.ph/file/0729cc082bf97347988f7.jpg",
        "https://telegra.ph/file/bb96d25df82178a2892e7.jpg",
        "https://telegra.ph/file/be73515791ea33be92a7d.jpg",
        "https://telegra.ph/file/fe234d6273093282d2dcc.jpg",
        "https://telegra.ph/file/66254bb72aa8094d38250.jpg",
        "https://telegra.ph/file/44bdaf37e5f7bdfc53ac6.jpg",
        "https://telegra.ph/file/e561ee1e1ca88db7e8038.jpg",
        "https://telegra.ph/file/f1960ccfc866b29ea5ad2.jpg",
        "https://telegra.ph/file/97622cad291472fb3c4aa.jpg",
        "https://telegra.ph/file/a46e316b413e9dc43e91b.jpg",
        "https://telegra.ph/file/497580fc3bddc21e0e162.jpg",
        "https://telegra.ph/file/3e86cc6cab06a6e2bde82.jpg",
        "https://telegra.ph/file/83140e2c57ddd95f310e6.jpg",
        "https://telegra.ph/file/2b20f8509d9437e94fed5.jpg",
        "https://telegra.ph/file/571960dcee4fce56698a4.jpg",
        "https://telegra.ph/file/25929a0b49452d8946c14.mp4",
        "https://telegra.ph/file/f5c9ceded3ee6e76a5931.jpg",
        "https://telegra.ph/file/a8bf6c6df8a48e4a306ca.jpg",
        "https://telegra.ph/file/af9e3f98da0bd937adf6e.jpg",
]

one_word = [ "AJA", "TERI", "MAA", "KI", "CHUT", "FAAD", "DUNGA", "HIJDE", "TERA", "BAAP", "HU", "KIDXX", "SPEED", "PAKAD", "BHEN KE LAUDE", "AA BETA", " ADITYA", "AAGYA", "TERI", "MAA ", "CHODNE", "AB", "TERI ", "MAA", "CHUDEGI", "KUTTE", "KI", "TARAH", "BETA", "TERI", "MAA", "KE", "BHOSDE", "ME", "JBL", "KE", "SPEAKER", "DAAL", "KAR", "BASS", "BOOSTED", "SONG", "SUNUNGA", "PURI", "RAAT", "LAGATAR", "TERI", "MAA", "KE", "SATH", "SEX", "KARUNGA🔥", "TERI", "MAA", "KE", "BOOBS", "DABAUNGA","XXX","TERI","MAA","KAA","CHUT","MARU","RANDI","KEE","PILEE","TERI","MAA","KAA","BHOSDAA","MARU","SUAR","KEE","CHODE","TERI","MAAA","KEEE","NUDES","BECHUNGA","RANDI","KEE","PILLE","TERI","MAAA","CHODU","SUAR","KEEE","PILEE","TERIII","MAAA","DAILYY","CHUDTTI","HAII","MADHARCHOD","AUKAT","BANAA","LODE","TERAA","BAAP","HUU","TERI","GFF","KAA","BHOSDAA","MARUU","MADHARCHOD","TERI ","NANAI","KAA","CHUTT","MARU","TERII","BEHEN","KAAA","BHOSDAA","MARU","RANDII","KEEE","CHODE","TERI","DADI","KAAA","BOOR","GARAM","KARR","TERE","PUREE","KHANDAN","KOOO","CHODUNGAA","BAAP","SEE","BAKCHODI","KAREGAA","SUARR","KEEE","PILLEE","NAAK","MEEE","NETAA","BAAP","KOO","KABHII","NAAH","BOLNAA","BETAA","CHUSS","LEEE","MERAA","LODAA","JAISE","ALUU","KAAA","PAKODAA","TERI","MAAA","BEHEN","GFF","NANI","DIIN","RAAT","SOTEE","JAGTEE","PELTAA","HUUU","LODEE","CHAAR","CHAWNII","GHODEE","PEEE","TUMM","MEREE","LODEE","PEE","TERI","MAA","KAAA","BOOBS","DABATA HU",]



""" RiZoeLX 2022 © pyRiZoeLX """

from pyrogram.errors import MessageDeleteForbidden, RPCError
from pyrogram.enums import ChatType

async def purge_(RiZoeL, message):
    if message.chat.type not in [ChatType.SUPERGROUP, ChatType.CHANNEL]:
        return

    status_message = await message.reply_text("...", quote=True)
    message_ids = []
    count_del_etion_s = 0

    if message.reply_to_message:
        try:
           for a_s_message_id in range(message.reply_to_message.id, message.id):
              message_ids.append(a_s_message_id)
              if len(message_ids) == 100:
                 count_del_etion_s += await RiZoeL.delete_messages(chat_id=message.chat.id, message_ids=message_ids, revoke=True)
                 message_ids = []
           if len(message_ids) > 0:
              count_del_etion_s += await RiZoeL.delete_messages(chat_id=message.chat.id, message_ids=message_ids, revoke=True)
        except MessageDeleteForbidden:
            await message.reply_text("Cannot delete all messages. The messages may be too old, I might not have delete rights, or this might not be a supergroup.")
            return
        except RPCError as ef:
            await message.reply_text(f"Some error occured! \n\n **Error:** `{ef}`")
            return
    await status_message.edit_text(f"deleted {count_del_etion_s} messages")
    await asyncio.sleep(5)
    await status_message.delete()
